@@ -50,12 +50,12 @@ use vars qw( $locale $Locale %locale );
     $locale = $opt_l;
     if ( ! defined( $locale_aliases{$locale} ) )
     {
-	my $dflt_locale = 'en_US.ISO8859-1';
+	my $dflt_locale = 'en';
 	warn "Warning: locale '$locale' not supported, using $dflt_locale\n"
 	    if length( $locale );
 	$locale = $dflt_locale;
     }
-    my $locale_alias = $locale_aliases{$locale};;
+    my $locale_alias = $locale_aliases{$locale};
     $Locale = "DebianDoc_SGML/Locale/$locale_alias/$format_alias";
     require $Locale;
     $Locale =~ s|/|::|g;
