@@ -48,7 +48,7 @@ if ( $DebianDoc_SGML::Format::Driver::opt_c )
 {
     my $locale = $DebianDoc_SGML::Format::Driver::locale;
     $locale =~ s/[\.@].*//;
-    my $language_tag = lc( locale2language_tag( $locale ) );
+    my $language_tag = lc( locale2language_tag( $DebianDoc_SGML::Format::Driver::opt_l ) );
     $language_tag = 'en' if $language_tag eq undef;
     my $charset = ".$locale{ 'charset' }"
 	if length( $locale{ 'charset' } )
@@ -128,7 +128,7 @@ sub _output_end_book
     $chapter_id = $topname;
     my $file = "$prefix$chapter_id$content$extension";
     push_output( 'file', File::Spec->catfile( "$directory", "$file" ) );
-    _html_head( $extension );
+    _html_head( "$content$extension" );
     if ( ! $DebianDoc_SGML::Format::Driver::opt_1 )
     {
         _html_tail();
@@ -190,7 +190,7 @@ sub _html_head
 
     my $locale = $DebianDoc_SGML::Format::Driver::locale;
     $locale =~ s/[\.@].*//;
-    my $language_tag = lc( locale2language_tag( $locale ) );
+    my $language_tag = lc( locale2language_tag( $DebianDoc_SGML::Format::Driver::opt_l ) );
     $language_tag = 'en' if $language_tag eq undef;
 
     output( "<book lang=\"$language_tag\">\n" );
