@@ -118,6 +118,10 @@ use vars qw( %locale_aliases );
 		   'ko_KR'			=> 'ko_KR.eucKR',
 		   'ko_KR.eucKR'		=> 'ko_KR.eucKR',
 
+		   'lt'				=> 'lt_LT.ISO8859-13',
+		   'lt_LT'			=> 'lt_LT.ISO8859-13',
+		   'lt_LT.ISO8859-13'		=> 'lt_LT.ISO8859-13',
+
 		   'nl'				=> 'nl_NL.ISO8859-1',
 		   'nl_NL'			=> 'nl_NL.ISO8859-1',
 		   'nl_NL.ISO8859-1'		=> 'nl_NL.ISO8859-1',
